@@ -44,7 +44,8 @@ static char RCS_id[] =
 int     command,
 	notnullflag,
 	keyflag,
-	outSock;
+	outSock,
+	msqlSelectLimit;
 
 char 	*curDB,
 	*arrayLen;
@@ -492,6 +493,12 @@ int msqlAddField(ident,type,length,notNull,priKey)
 	return(0);
 }
 
+msqlSetSelectLimit(value)
+	val_t	*value;
+{
+	msqlSelectLimit = value->val.intVal;
+}
+
 
 msqlAddFieldValue(value)
 	val_t	*value;
